@@ -28,6 +28,8 @@
 #include <string.h>
 #endif
 
+#include <libxfce4ui/libxfce4ui.h>
+
 #include <thunar/thunar-abstract-dialog.h>
 #include <thunar/thunar-application.h>
 #include <thunar/thunar-dialogs.h>
@@ -62,73 +64,82 @@ enum
 
 
 
-static void     thunar_renamer_dialog_dispose             (GObject                  *object);
-static void     thunar_renamer_dialog_finalize            (GObject                  *object);
-static void     thunar_renamer_dialog_get_property        (GObject                  *object,
-                                                           guint                     prop_id,
-                                                           GValue                   *value,
-                                                           GParamSpec               *pspec);
-static void     thunar_renamer_dialog_set_property        (GObject                  *object,
-                                                           guint                     prop_id,
-                                                           const GValue             *value,
-                                                           GParamSpec               *pspec);
-static void     thunar_renamer_dialog_realize             (GtkWidget                *widget);
-static void     thunar_renamer_dialog_unrealize           (GtkWidget                *widget);
-static void     thunar_renamer_dialog_response            (GtkDialog                *dialog,
-                                                           gint                      response);
-static void     thunar_renamer_dialog_context_menu        (ThunarRenamerDialog      *renamer_dialog,
-                                                           guint                     button,
-                                                           guint32                   timestamp);
-static void     thunar_renamer_dialog_help                (ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_save                (ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_action_add_files    (GtkAction                *action,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_action_remove_files (GtkAction                *action,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_action_clear        (GtkAction                *action,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_action_about        (GtkAction                *action,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_action_properties   (GtkAction                *action,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static gboolean thunar_renamer_dialog_button_press_event  (GtkWidget                *tree_view,
-                                                           GdkEventButton           *event,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_drag_data_received  (GtkWidget                *tree_view,
-                                                           GdkDragContext           *context,
-                                                           gint                      x,
-                                                           gint                      y,
-                                                           GtkSelectionData         *selection_data,
-                                                           guint                     info,
-                                                           guint                     timestamp,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_drag_leave          (GtkWidget                *tree_view,
-                                                           GdkDragContext           *context,
-                                                           guint                     timestamp,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static gboolean thunar_renamer_dialog_drag_motion         (GtkWidget                *tree_view,
-                                                           GdkDragContext           *context,
-                                                           gint                      x,
-                                                           gint                      y,
-                                                           guint                     timestamp,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static gboolean thunar_renamer_dialog_drag_drop           (GtkWidget                *tree_view,
-                                                           GdkDragContext           *context,
-                                                           gint                      x,
-                                                           gint                      y,
-                                                           guint                     timestamp,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_notify_page         (GtkNotebook              *notebook,
-                                                           GParamSpec               *pspec,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static gboolean thunar_renamer_dialog_popup_menu          (GtkWidget                *tree_view,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_row_activated       (GtkTreeView              *tree_view,
-                                                           GtkTreePath              *path,
-                                                           GtkTreeViewColumn        *column,
-                                                           ThunarRenamerDialog      *renamer_dialog);
-static void     thunar_renamer_dialog_selection_changed   (GtkTreeSelection         *selection,
-                                                           ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_dispose               (GObject                  *object);
+static void        thunar_renamer_dialog_finalize              (GObject                  *object);
+static void        thunar_renamer_dialog_get_property          (GObject                  *object,
+                                                                guint                     prop_id,
+                                                                GValue                   *value,
+                                                                GParamSpec               *pspec);
+static void        thunar_renamer_dialog_set_property          (GObject                  *object,
+                                                                guint                     prop_id,
+                                                                const GValue             *value,
+                                                                GParamSpec               *pspec);
+static void        thunar_renamer_dialog_realize               (GtkWidget                *widget);
+static void        thunar_renamer_dialog_unrealize             (GtkWidget                *widget);
+static void        thunar_renamer_dialog_response              (GtkDialog                *dialog,
+                                                                gint                      response);
+static void        thunar_renamer_dialog_context_menu          (ThunarRenamerDialog      *renamer_dialog,
+                                                                guint                     button,
+                                                                guint32                   timestamp);
+static void        thunar_renamer_dialog_help                  (ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_save                  (ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_action_add_files      (GtkAction                *action,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_action_remove_files   (GtkAction                *action,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_action_clear          (GtkAction                *action,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_action_about          (GtkAction                *action,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_action_properties     (GtkAction                *action,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_name_column_clicked   (GtkTreeViewColumn        *column,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_button_press_event    (GtkWidget                *tree_view,
+                                                                GdkEventButton           *event,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_drag_data_received    (GtkWidget                *tree_view,
+                                                                GdkDragContext           *context,
+                                                                gint                      x,
+                                                                gint                      y,
+                                                                GtkSelectionData         *selection_data,
+                                                                guint                     info,
+                                                                guint                     timestamp,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_drag_leave            (GtkWidget                *tree_view,
+                                                                GdkDragContext           *context,
+                                                                guint                     timestamp,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_drag_motion           (GtkWidget                *tree_view,
+                                                                GdkDragContext           *context,
+                                                                gint                      x,
+                                                                gint                      y,
+                                                                guint                     timestamp,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_drag_drop             (GtkWidget                *tree_view,
+                                                                GdkDragContext           *context,
+                                                                gint                      x,
+                                                                gint                      y,
+                                                                guint                     timestamp,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_notify_page           (GtkNotebook              *notebook,
+                                                                GParamSpec               *pspec,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static gboolean    thunar_renamer_dialog_popup_menu            (GtkWidget                *tree_view,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_row_activated         (GtkTreeView              *tree_view,
+                                                                GtkTreePath              *path,
+                                                                GtkTreeViewColumn        *column,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static void        thunar_renamer_dialog_selection_changed     (GtkTreeSelection         *selection,
+                                                                ThunarRenamerDialog      *renamer_dialog);
+static ThunarFile *thunar_renamer_dialog_get_current_directory (ThunarRenamerDialog *renamer_dialog);
+static void        thunar_renamer_dialog_set_current_directory (ThunarRenamerDialog *renamer_dialog,
+                                                                ThunarFile          *current_directory);
+static GList      *thunar_renamer_dialog_get_selected_files    (ThunarRenamerDialog *renamer_dialog);
+static gboolean    thunar_renamer_dialog_get_standalone        (ThunarRenamerDialog *renamer_dialog);
+static void        thunar_renamer_dialog_set_standalone        (ThunarRenamerDialog *renamer_dialog,
+                                                                gboolean             fixed);
 
 
 
@@ -157,6 +168,8 @@ struct _ThunarRenamerDialog
   GtkWidget           *tree_view;
   GtkWidget           *progress;
 
+  GtkTreeViewColumn   *name_column;
+
   /* the current directory used for the "Add Files" dialog */
   ThunarFile          *current_directory;
 
@@ -278,7 +291,8 @@ static gint
 trd_renamer_compare (gconstpointer a,
                      gconstpointer b)
 {
-  return g_utf8_collate (thunarx_renamer_get_name (THUNARX_RENAMER (a)), thunarx_renamer_get_name (THUNARX_RENAMER (b)));
+  return g_utf8_collate (thunarx_renamer_get_name (THUNARX_RENAMER (a)),
+                         thunarx_renamer_get_name (THUNARX_RENAMER (b)));
 }
 
 
@@ -334,7 +348,6 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   g_list_free (providers);
 
   /* initialize the dialog */
-  gtk_dialog_set_has_separator (GTK_DIALOG (renamer_dialog), FALSE);
   gtk_window_set_default_size (GTK_WINDOW (renamer_dialog), 510, 490);
   gtk_window_set_title (GTK_WINDOW (renamer_dialog), _("Rename Multiple Files"));
 
@@ -388,8 +401,7 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   gtk_widget_show (swin);
 
   /* create the tree view */
-  renamer_dialog->tree_view = exo_tree_view_new ();
-  gtk_tree_view_set_model (GTK_TREE_VIEW (renamer_dialog->tree_view), GTK_TREE_MODEL (renamer_dialog->model));
+  renamer_dialog->tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (renamer_dialog->model));
   gtk_tree_view_set_search_column (GTK_TREE_VIEW (renamer_dialog->tree_view), THUNAR_RENAMER_MODEL_COLUMN_OLDNAME);
   gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (renamer_dialog->tree_view), TRUE);
   gtk_tree_view_set_enable_search (GTK_TREE_VIEW (renamer_dialog->tree_view), TRUE);
@@ -402,17 +414,19 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   gtk_widget_show (renamer_dialog->tree_view);
 
   /* create the tree view column for the old file name */
-  column = gtk_tree_view_column_new ();
+  renamer_dialog->name_column = column = gtk_tree_view_column_new ();
   gtk_tree_view_column_set_spacing (column, 2);
   gtk_tree_view_column_set_min_width (column, 100);
   gtk_tree_view_column_set_title (column, _("Name"));
   gtk_tree_view_column_set_resizable (column, TRUE);
   gtk_tree_view_column_set_fixed_width (column, 250);
   gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
+  gtk_tree_view_column_set_clickable (column, TRUE);
+  g_signal_connect (G_OBJECT (column), "clicked", G_CALLBACK (thunar_renamer_dialog_name_column_clicked), renamer_dialog);
   renderer = g_object_new (THUNAR_TYPE_ICON_RENDERER, "size", 16, NULL);
   gtk_tree_view_column_pack_start (column, renderer, FALSE);
   gtk_tree_view_column_set_attributes (column, renderer, "file", THUNAR_RENAMER_MODEL_COLUMN_FILE, NULL);
-  renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ellipsize", PANGO_ELLIPSIZE_END, "ellipsize-set", TRUE, NULL);
+  renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
   gtk_tree_view_column_set_attributes (column, renderer, "text", THUNAR_RENAMER_MODEL_COLUMN_OLDNAME, NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (renamer_dialog->tree_view), column);
@@ -425,15 +439,13 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
   gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
   renderer = g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
                            "ellipsize", PANGO_ELLIPSIZE_END,
-                           "ellipsize-set", TRUE,
                            "foreground", "Red",
-                           "weight", PANGO_WEIGHT_SEMIBOLD,
                            NULL);
   gtk_tree_view_column_pack_start (column, renderer, TRUE);
   gtk_tree_view_column_set_attributes (column, renderer,
                                        "foreground-set", THUNAR_RENAMER_MODEL_COLUMN_CONFLICT,
                                        "text", THUNAR_RENAMER_MODEL_COLUMN_NEWNAME,
-                                       "weight-set", THUNAR_RENAMER_MODEL_COLUMN_CONFLICT,
+                                       "weight", THUNAR_RENAMER_MODEL_COLUMN_CONFLICT_WEIGHT,
                                        NULL);
   gtk_tree_view_append_column (GTK_TREE_VIEW (renamer_dialog->tree_view), column);
 
@@ -478,9 +490,9 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
       xfce_rc_set_group (rc, "Configuration");
 
       /* create the renamer combo box for the renamer selection */
-      rcombo = gtk_combo_box_new_text ();
+      rcombo = gtk_combo_box_text_new ();
       for (lp = renamers; lp != NULL; lp = lp->next)
-        gtk_combo_box_append_text (GTK_COMBO_BOX (rcombo), thunarx_renamer_get_name (lp->data));
+        gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (rcombo), thunarx_renamer_get_name (lp->data));
       gtk_box_pack_start (GTK_BOX (rbox), rcombo, FALSE, FALSE, 0);
       gtk_widget_show (rcombo);
 
@@ -496,14 +508,14 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
       gtk_widget_show (image);
 
       /* create the name/suffix/both combo box */
-      mcombo = gtk_combo_box_new_text ();
+      mcombo = gtk_combo_box_text_new ();
       klass = g_type_class_ref (THUNAR_TYPE_RENAMER_MODE);
       active_str = xfce_rc_read_entry_untranslated (rc, "LastActiveMode", "");
       for (active = 0, n = 0; n < klass->n_values; ++n)
         {
           if (exo_str_is_equal (active_str, klass->values[n].value_name))
             active = n;
-          gtk_combo_box_append_text (GTK_COMBO_BOX (mcombo), _(klass->values[n].value_nick));
+          gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (mcombo), _(klass->values[n].value_nick));
         }
       exo_mutual_binding_new (G_OBJECT (renamer_dialog->model), "mode", G_OBJECT (mcombo), "active");
       gtk_box_pack_end (GTK_BOX (rbox), mcombo, FALSE, FALSE, 0);
@@ -606,8 +618,7 @@ thunar_renamer_dialog_init (ThunarRenamerDialog *renamer_dialog)
     }
 
   /* release the renamers list */
-  g_list_foreach (renamers, (GFunc) g_object_unref, NULL);
-  g_list_free (renamers);
+  g_list_free_full (renamers, g_object_unref);
 }
 
 
@@ -928,7 +939,8 @@ thunar_renamer_dialog_help (ThunarRenamerDialog *renamer_dialog)
   if (G_LIKELY (help_url == NULL))
     {
       /* open the general documentation if no specific URL */
-      thunar_dialogs_show_help (GTK_WIDGET (renamer_dialog), "advanced-topics", "to-bulk-rename-files");
+      xfce_dialog_show_help (GTK_WINDOW (renamer_dialog), "thunar",
+                             "advanced-topics", "to-bulk-rename-files");
     }
   else
     {
@@ -1095,6 +1107,9 @@ thunar_renamer_dialog_action_add_files (GtkAction           *action,
               /* append the file to the renamer model */
               thunar_renamer_model_append (renamer_dialog->model, file);
 
+              /* unset sort order */
+              gtk_tree_view_column_set_sort_indicator (renamer_dialog->name_column, FALSE);
+
               /* release the file */
               g_object_unref (G_OBJECT (file));
             }
@@ -1214,17 +1229,42 @@ thunar_renamer_dialog_action_properties (GtkAction           *action,
   _thunar_return_if_fail (GTK_IS_ACTION (action));
   _thunar_return_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog));
 
-  /* verify that we have exactly one file selected */
-  if (G_LIKELY (g_list_length (renamer_dialog->selected_files) == 1))
+  /* popup the properties dialog */
+  dialog = thunar_properties_dialog_new (GTK_WINDOW (renamer_dialog));
+  gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+  thunar_properties_dialog_set_files (THUNAR_PROPERTIES_DIALOG (dialog), renamer_dialog->selected_files);
+  gtk_widget_show (dialog);
+}
+
+
+
+static void
+thunar_renamer_dialog_name_column_clicked (GtkTreeViewColumn   *column,
+                                           ThunarRenamerDialog *renamer_dialog)
+{
+  GtkSortType sort_order = GTK_SORT_ASCENDING;
+
+  _thunar_return_if_fail (renamer_dialog->name_column == column);
+
+  if (!gtk_tree_view_column_get_sort_indicator (column))
     {
-      /* popup the properties dialog */
-      dialog = thunar_properties_dialog_new ();
-      gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-      gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
-      gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (renamer_dialog));
-      thunar_properties_dialog_set_file (THUNAR_PROPERTIES_DIALOG (dialog), renamer_dialog->selected_files->data);
-      gtk_widget_show (dialog);
+      /* show sort order */
+      gtk_tree_view_column_set_sort_indicator (column, TRUE);
     }
+  else
+    {
+      /* invert new sort order */
+      if (gtk_tree_view_column_get_sort_order (column) == GTK_SORT_ASCENDING)
+        sort_order = GTK_SORT_DESCENDING;
+      else
+        sort_order = GTK_SORT_ASCENDING;
+    }
+
+  /* set new sort direction */
+  gtk_tree_view_column_set_sort_order (column, sort_order);
+
+  /* sort the model */
+  thunar_renamer_model_sort (renamer_dialog->model, sort_order);
 }
 
 
@@ -1340,6 +1380,9 @@ thunar_renamer_dialog_drag_data_received (GtkWidget           *tree_view,
               /* insert the file in the model */
               thunar_renamer_model_insert (renamer_dialog->model, file, position);
 
+              /* unset sort order */
+              gtk_tree_view_column_set_sort_indicator (renamer_dialog->name_column, FALSE);
+
               /* advance the offset if we do not append, so the drop order is consistent */
               if (position != -1)
                 position++;
@@ -1520,9 +1563,14 @@ thunar_renamer_dialog_drag_drop (GtkWidget           *tree_view,
             }
 
           /* perform the move */
-          thunar_renamer_model_reorder (renamer_dialog->model, rows, position);
-          g_list_foreach (rows, (GFunc) gtk_tree_path_free, NULL);
-          g_list_free (rows);
+          if (G_LIKELY (rows != NULL))
+            {
+              thunar_renamer_model_reorder (renamer_dialog->model, rows, position);
+              g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
+            }
+
+          /* unset sort column */
+          gtk_tree_view_column_set_sort_indicator (renamer_dialog->name_column, FALSE);
         }
 
       /* finish the dnd operation */
@@ -1648,7 +1696,7 @@ thunar_renamer_dialog_selection_changed (GtkTreeSelection    *selection,
 
   /* the "Properties" action is only sensitive if we have exactly one selected file */
   action = gtk_action_group_get_action (renamer_dialog->action_group, "properties");
-  gtk_action_set_sensitive (action, (n_selected_files == 1));
+  gtk_action_set_sensitive (action, n_selected_files > 0);
 
   /* notify listeners */
   g_object_notify (G_OBJECT (renamer_dialog), "selected-files");
@@ -1656,22 +1704,6 @@ thunar_renamer_dialog_selection_changed (GtkTreeSelection    *selection,
 
 
 
-/**
- * thunar_renamer_dialog_new:
- *
- * Allocates a new #ThunarRenamerDialog instance.
- *
- * Return value: the newly allocated #ThunarRenamerDialog
- *               instance.
- **/
-GtkWidget*
-thunar_renamer_dialog_new (void)
-{
-  return g_object_new (THUNAR_TYPE_RENAMER_DIALOG, NULL);
-}
-
-
-
 /**
  * thunar_renamer_dialog_get_current_directory:
  * @renamer_dialog : a #ThunarRenamerDialog.
@@ -1683,7 +1715,7 @@ thunar_renamer_dialog_new (void)
  *
  * Return value: the current directory for @renamer_dialog.
  **/
-ThunarFile*
+static ThunarFile*
 thunar_renamer_dialog_get_current_directory (ThunarRenamerDialog *renamer_dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), NULL);
@@ -1702,7 +1734,7 @@ thunar_renamer_dialog_get_current_directory (ThunarRenamerDialog *renamer_dialog
  * is %NULL, the current directory of the file manager process
  * will be used.
  **/
-void
+static void
 thunar_renamer_dialog_set_current_directory (ThunarRenamerDialog *renamer_dialog,
                                              ThunarFile          *current_directory)
 {
@@ -1739,7 +1771,7 @@ thunar_renamer_dialog_set_current_directory (ThunarRenamerDialog *renamer_dialog
  *
  * Return value: the list of currently selected files.
  **/
-GList*
+static GList*
 thunar_renamer_dialog_get_selected_files (ThunarRenamerDialog *renamer_dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), NULL);
@@ -1758,7 +1790,7 @@ thunar_renamer_dialog_get_selected_files (ThunarRenamerDialog *renamer_dialog)
  *
  * Return value: %TRUE if @renamer_dialog is standalone.
  **/
-gboolean
+static gboolean
 thunar_renamer_dialog_get_standalone (ThunarRenamerDialog *renamer_dialog)
 {
   _thunar_return_val_if_fail (THUNAR_IS_RENAMER_DIALOG (renamer_dialog), FALSE);
@@ -1776,7 +1808,7 @@ thunar_renamer_dialog_get_standalone (ThunarRenamerDialog *renamer_dialog)
  * toolbar and several other actions that do not make sense
  * when opened from within the file manager.
  **/
-void
+static void
 thunar_renamer_dialog_set_standalone (ThunarRenamerDialog *renamer_dialog,
                                       gboolean             standalone)
 {
@@ -1877,7 +1909,7 @@ thunar_show_renamer_dialog (gpointer     parent,
     gtk_window_set_startup_id (GTK_WINDOW (dialog), startup_id);
 
   /* check if we have a toplevel window */
-  if (G_LIKELY (window != NULL && GTK_WIDGET_TOPLEVEL (window)))
+  if (G_LIKELY (window != NULL && gtk_widget_get_toplevel (window)))
     {
       /* dialog is transient for toplevel window, but not modal */
       gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
